summaryrefslogtreecommitdiff
diff options
context:
space:
mode:
-rw-r--r--ANNOUNCE5
-rw-r--r--CHANGES6
-rw-r--r--LICENSE4
-rw-r--r--Makefile.in2
-rw-r--r--README2
-rw-r--r--arm/arm_init.c4
-rw-r--r--libpng-manual.txt6
-rw-r--r--libpng.314
-rw-r--r--libpngpf.32
-rw-r--r--png.52
-rw-r--r--png.c4
-rw-r--r--png.h10
-rw-r--r--pngconf.h2
-rw-r--r--projects/vstudio/readme.txt2
-rw-r--r--projects/vstudio/zlib.props2
-rw-r--r--scripts/README.txt2
-rw-r--r--scripts/pnglibconf.h.prebuilt2
17 files changed, 37 insertions, 34 deletions
diff --git a/ANNOUNCE b/ANNOUNCE
index 93ffba5c1..90d8a8d1d 100644
--- a/ANNOUNCE
+++ b/ANNOUNCE
@@ -1,5 +1,5 @@
-Libpng 1.5.15beta05 - February 16, 2013
+Libpng 1.5.15beta05 - February 18, 2013
This is not intended to be a public release. It will be replaced
within a few weeks by a public version or by another test version.
@@ -49,12 +49,13 @@ Version 1.5.15beta04 [February 15, 2013]
Enclosed the new png_get_palette_max in #ifdef PNG_GET_PALETTE_MAX_SUPPORTED
block, and revised pnglibconf.h and pnglibconf.h.prebuilt accordingly.
-Version 1.5.15beta05 [February 16, 2013]
+Version 1.5.15beta05 [February 18, 2013]
Use approved/supported Android method to check for NEON, use Linux/POSIX
1003.1 API to check /proc/self/auxv avoiding buffer allocation and other
library calls.
Fixed a race condition in the creation of the build 'scripts' directory
while building with a parallel make.
+ Use parentheses more consistently in "#if define(MACRO)" tests.
Send comments/corrections/commendations to png-mng-implement at lists.sf.net
(subscription required; visit
diff --git a/CHANGES b/CHANGES
index 1fa393a5e..88fabb3da 100644
--- a/CHANGES
+++ b/CHANGES
@@ -3672,7 +3672,8 @@ Version 1.5.6 [November 3, 2011]
No changes.
Version 1.5.7beta01 [November 4, 2011]
- Added support for ARM processor (Mans Rullgard)
+ Added support for ARM processor, when decoding all PNG up-filtered rows
+ and any other-filtered rows with 3 or 4 bytes per pixel (Mans Rullgard).
Fixed bug in pngvalid on early allocation failure; fixed type cast in
pngmem.c; pngvalid would attempt to call png_error() if the allocation
of a png_struct or png_info failed. This would probably have led to a
@@ -4006,12 +4007,13 @@ Version 1.5.15beta04 [February 15, 2013]
Enclosed the new png_get_palette_max in #ifdef PNG_GET_PALETTE_MAX_SUPPORTED
block, and revised pnglibconf.h and pnglibconf.h.prebuilt accordingly.
-Version 1.5.15beta05 [February 16, 2013]
+Version 1.5.15beta05 [February 18, 2013]
Use approved/supported Android method to check for NEON, use Linux/POSIX
1003.1 API to check /proc/self/auxv avoiding buffer allocation and other
library calls.
Fixed a race condition in the creation of the build 'scripts' directory
while building with a parallel make.
+ Use parentheses more consistently in "#if define(MACRO)" tests.
===========================================================================
NOTICE November 17, 2012:
diff --git a/LICENSE b/LICENSE
index e5b214301..658eb7485 100644
--- a/LICENSE
+++ b/LICENSE
@@ -10,7 +10,7 @@ this sentence.
This code is released under the libpng license.
-libpng versions 1.2.6, August 15, 2004, through 1.5.15beta05, February 15, 2013, are
+libpng versions 1.2.6, August 15, 2004, through 1.5.15beta05, February 18, 2013, are
Copyright (c) 2004, 2006-2012 Glenn Randers-Pehrson, and are
distributed according to the same disclaimer and license as libpng-1.2.5
with the following individual added to the list of Contributing Authors
@@ -108,4 +108,4 @@ certification mark of the Open Source Initiative.
Glenn Randers-Pehrson
glennrp at users.sourceforge.net
-February 15, 2013
+February 18, 2013
diff --git a/Makefile.in b/Makefile.in
index 6d66b5c5e..bc1c9549a 100644
--- a/Makefile.in
+++ b/Makefile.in
@@ -1496,7 +1496,7 @@ contrib/libtests/pngvalid.o pngtest.o: pnglibconf.h
.dfn.out:
rm -f $@ $@.c $@.?
- test -d scripts || mkdir scripts
+ test -d scripts || mkdir scripts || test -d scripts
echo '#include "$<"' >$@.c
$(DFNCPP) $(DEFS) $(DEFAULT_INCLUDES) $(INCLUDES) @LIBPNG_DEFINES@\
$(CPPFLAGS) $(SYMBOL_CFLAGS) $@.c > $@.1
diff --git a/README b/README
index 268e3c6c8..42bc51521 100644
--- a/README
+++ b/README
@@ -1,4 +1,4 @@
-README for libpng version 1.5.15beta05 - February 15, 2013 (shared library 15.0)
+README for libpng version 1.5.15beta05 - February 18, 2013 (shared library 15.0)
See the note about version numbers near the top of png.h
See INSTALL for instructions on how to install libpng.
diff --git a/arm/arm_init.c b/arm/arm_init.c
index 3a3e86e64..2042180ec 100644
--- a/arm/arm_init.c
+++ b/arm/arm_init.c
@@ -3,7 +3,7 @@
*
* Copyright (c) 2013 Glenn Randers-Pehrson
* Written by Mans Rullgard, 2011.
- * Last changed in libpng 1.5.14 [(PENDING RELEASE)]
+ * Last changed in libpng 1.5.15 [%RDATE%]
*
* This code is released under the libpng license.
* For conditions of distribution and use, see the disclaimer
@@ -56,7 +56,7 @@ png_have_neon(png_structp png_ptr)
#include <elf.h>
#include <asm/hwcap.h>
-/* A read call may be interupted, in which case it returns -1 and sets errno to
+/* A read call may be interrupted, in which case it returns -1 and sets errno to
* EINTR if nothing was done, otherwise (if something was done) a partial read
* may result.
*/
diff --git a/libpng-manual.txt b/libpng-manual.txt
index bbd33f3e4..1cf5853ea 100644
--- a/libpng-manual.txt
+++ b/libpng-manual.txt
@@ -1,6 +1,6 @@
Libpng-manual.txt - A description on how to use and modify libpng
- libpng version 1.5.15beta05 - February 17, 2013
+ libpng version 1.5.15beta05 - February 18, 2013
Updated and distributed by Glenn Randers-Pehrson
<glennrp at users.sourceforge.net>
Copyright (c) 1998-2013 Glenn Randers-Pehrson
@@ -11,7 +11,7 @@ Libpng-manual.txt - A description on how to use and modify libpng
Based on:
- libpng versions 0.97, January 1998, through 1.5.15beta05 - February 17, 2013
+ libpng versions 0.97, January 1998, through 1.5.15beta05 - February 18, 2013
Updated and distributed by Glenn Randers-Pehrson
Copyright (c) 1998-2013 Glenn Randers-Pehrson
@@ -4622,7 +4622,7 @@ Other rules can be inferred by inspecting the libpng source.
XIV. Y2K Compliance in libpng
-February 17, 2013
+February 18, 2013
Since the PNG Development group is an ad-hoc body, we can't make
an official declaration.
diff --git a/libpng.3 b/libpng.3
index e033bc825..b1fe8b393 100644
--- a/libpng.3
+++ b/libpng.3
@@ -1,4 +1,4 @@
-.TH LIBPNG 3 "February 17, 2013"
+.TH LIBPNG 3 "February 18, 2013"
.SH NAME
libpng \- Portable Network Graphics (PNG) Reference Library 1.5.15beta05
.SH SYNOPSIS
@@ -492,7 +492,7 @@ Following is a copy of the libpng-manual.txt file that accompanies libpng.
.SH LIBPNG.TXT
Libpng-manual.txt - A description on how to use and modify libpng
- libpng version 1.5.15beta05 - February 17, 2013
+ libpng version 1.5.15beta05 - February 18, 2013
Updated and distributed by Glenn Randers-Pehrson
<glennrp at users.sourceforge.net>
Copyright (c) 1998-2013 Glenn Randers-Pehrson
@@ -503,7 +503,7 @@ Libpng-manual.txt - A description on how to use and modify libpng
Based on:
- libpng versions 0.97, January 1998, through 1.5.15beta05 - February 17, 2013
+ libpng versions 0.97, January 1998, through 1.5.15beta05 - February 18, 2013
Updated and distributed by Glenn Randers-Pehrson
Copyright (c) 1998-2013 Glenn Randers-Pehrson
@@ -5115,7 +5115,7 @@ Other rules can be inferred by inspecting the libpng source.
.SH XIV. Y2K Compliance in libpng
-February 17, 2013
+February 18, 2013
Since the PNG Development group is an ad-hoc body, we can't make
an official declaration.
@@ -5401,7 +5401,7 @@ possible without all of you.
Thanks to Frank J. T. Wojcik for helping with the documentation.
-Libpng version 1.5.15beta05 - February 17, 2013:
+Libpng version 1.5.15beta05 - February 18, 2013:
Initially created in 1995 by Guy Eric Schalnat, then of Group 42, Inc.
Currently maintained by Glenn Randers-Pehrson (glennrp at users.sourceforge.net).
@@ -5424,7 +5424,7 @@ this sentence.
This code is released under the libpng license.
-libpng versions 1.2.6, August 15, 2004, through 1.5.15beta05, February 17, 2013, are
+libpng versions 1.2.6, August 15, 2004, through 1.5.15beta05, February 18, 2013, are
Copyright (c) 2004,2006-2007 Glenn Randers-Pehrson, and are
distributed according to the same disclaimer and license as libpng-1.2.5
with the following individual added to the list of Contributing Authors
@@ -5523,7 +5523,7 @@ certification mark of the Open Source Initiative.
Glenn Randers-Pehrson
glennrp at users.sourceforge.net
-February 17, 2013
+February 18, 2013
.\" end of man page
diff --git a/libpngpf.3 b/libpngpf.3
index bbb4a0a33..1aae3cd54 100644
--- a/libpngpf.3
+++ b/libpngpf.3
@@ -1,4 +1,4 @@
-.TH LIBPNGPF 3 "February 15, 2013"
+.TH LIBPNGPF 3 "February 18, 2013"
.SH NAME
libpng \- Portable Network Graphics (PNG) Reference Library 1.5.15beta05
(private functions)
diff --git a/png.5 b/png.5
index 726867c29..918508520 100644
--- a/png.5
+++ b/png.5
@@ -1,4 +1,4 @@
-.TH PNG 5 "February 15, 2013"
+.TH PNG 5 "February 18, 2013"
.SH NAME
png \- Portable Network Graphics (PNG) format
.SH DESCRIPTION
diff --git a/png.c b/png.c
index 864b04706..9b6509e2d 100644
--- a/png.c
+++ b/png.c
@@ -658,13 +658,13 @@ png_get_copyright(png_const_structp png_ptr)
#else
# ifdef __STDC__
return PNG_STRING_NEWLINE \
- "libpng version 1.5.15beta05 - February 17, 2013" PNG_STRING_NEWLINE \
+ "libpng version 1.5.15beta05 - February 18, 2013" PNG_STRING_NEWLINE \
"Copyright (c) 1998-2013 Glenn Randers-Pehrson" PNG_STRING_NEWLINE \
"Copyright (c) 1996-1997 Andreas Dilger" PNG_STRING_NEWLINE \
"Copyright (c) 1995-1996 Guy Eric Schalnat, Group 42, Inc." \
PNG_STRING_NEWLINE;
# else
- return "libpng version 1.5.15beta05 - February 17, 2013\
+ return "libpng version 1.5.15beta05 - February 18, 2013\
Copyright (c) 1998-2013 Glenn Randers-Pehrson\
Copyright (c) 1996-1997 Andreas Dilger\
Copyright (c) 1995-1996 Guy Eric Schalnat, Group 42, Inc.";
diff --git a/pngconf.h b/pngconf.h
index 07cd3571d..1e10b37d1 100644
--- a/pngconf.h
+++ b/pngconf.h
@@ -1,7 +1,7 @@
/* pngconf.h - machine configurable file for libpng
*
- * libpng version 1.5.15beta05 - February 17, 2013
+ * libpng version 1.5.15beta05 - February 18, 2013
*
* Copyright (c) 1998-2013 Glenn Randers-Pehrson
* (Version 0.96 Copyright (c) 1996, 1997 Andreas Dilger)
diff --git a/projects/vstudio/readme.txt b/projects/vstudio/readme.txt
index e88809dc9..6f380b2ba 100644
--- a/projects/vstudio/readme.txt
+++ b/projects/vstudio/readme.txt
@@ -1,7 +1,7 @@
VisualStudio instructions
-libpng version 1.5.15beta05 - February 15, 2013
+libpng version 1.5.15beta05 - February 18, 2013
Copyright (c) 1998-2010 Glenn Randers-Pehrson
diff --git a/projects/vstudio/zlib.props b/projects/vstudio/zlib.props
index 3691548b1..346668564 100644
--- a/projects/vstudio/zlib.props
+++ b/projects/vstudio/zlib.props
@@ -2,7 +2,7 @@
<!--
* zlib.props - location of zlib source
*
- * libpng version 1.5.15beta05 - February 15, 2013
+ * libpng version 1.5.15beta05 - February 18, 2013
*
* Copyright (c) 1998-2011 Glenn Randers-Pehrson
*
diff --git a/scripts/README.txt b/scripts/README.txt
index 866fa3264..ba66a27c1 100644
--- a/scripts/README.txt
+++ b/scripts/README.txt
@@ -1,5 +1,5 @@
-Makefiles for libpng version 1.5.15beta05 - February 15, 2013
+Makefiles for libpng version 1.5.15beta05 - February 18, 2013
pnglibconf.h.prebuilt => Stores configuration settings
makefile.linux => Linux/ELF makefile
diff --git a/scripts/pnglibconf.h.prebuilt b/scripts/pnglibconf.h.prebuilt
index 0c3ff3802..888e27aea 100644
--- a/scripts/pnglibconf.h.prebuilt
+++ b/scripts/pnglibconf.h.prebuilt
@@ -3,7 +3,7 @@
/* pnglibconf.h - library build configuration */
-/* Libpng 1.5.15beta05 - February 15, 2013 */
+/* Libpng 1.5.15beta05 - February 18, 2013 */
/* Copyright (c) 1998-2012 Glenn Randers-Pehrson */
diff --git a/png.h b/png.h
index 60ddafe68..478b068cf 100644
--- a/png.h
+++ b/png.h
@@ -1,7 +1,7 @@
/* png.h - header file for PNG reference library
*
* libpng version 1.5.15beta05 - February 17, 2013
* Copyright (c) 1998-2013 Glenn Randers-Pehrson
* (Version 0.96 Copyright (c) 1996, 1997 Andreas Dilger)
* (Version 0.88 Copyright (c) 1995, 1996 Guy Eric Schalnat, Group 42, Inc.)
@@ -11,7 +11,7 @@
* Authors and maintainers:
* libpng versions 0.71, May 1995, through 0.88, January 1996: Guy Schalnat
* libpng versions 0.89c, June 1996, through 0.96, May 1997: Andreas Dilger
* libpng versions 0.97, January 1998, through 1.5.15beta05 - February 17, 2013: Glenn
* See also "Contributing Authors", below.
*
* Note about libpng version numbers:
@@ -216,7 +216,7 @@
*
* This code is released under the libpng license.
*
* libpng versions 1.2.6, August 15, 2004, through 1.5.15beta05, February 17, 2013, are
* Copyright (c) 2004, 2006-2013 Glenn Randers-Pehrson, and are
* distributed according to the same disclaimer and license as libpng-1.2.5
* with the following individual added to the list of Contributing Authors:
@@ -328,7 +328,7 @@
* Y2K compliance in libpng:
* =========================
*
- * February 17, 2013
+ * February 18, 2013
*
* Since the PNG Development group is an ad-hoc body, we can't make
* an official declaration.
@@ -395,7 +395,7 @@
/* Version information for png.h - this should match the version in png.c */
#define PNG_LIBPNG_VER_STRING "1.5.15beta05"
#define PNG_HEADER_VERSION_STRING \
- " libpng version 1.5.15beta05 - February 17, 2013\n"
+ " libpng version 1.5.15beta05 - February 18, 2013\n"
#define PNG_LIBPNG_VER_SONUM 15
#define PNG_LIBPNG_VER_DLLNUM 15
@@ -1,7 +1,7 @@
/* png.h - header file for PNG reference library
*
- * libpng version 1.5.15beta05 - February 17, 2013
+ * libpng version 1.5.15beta05 - February 18, 2013
* Copyright (c) 1998-2013 Glenn Randers-Pehrson
* (Version 0.96 Copyright (c) 1996, 1997 Andreas Dilger)
@@ -11,7 +11,7 @@
* libpng versions 0.71, May 1995, through 0.88, January 1996: Guy Schalnat
* libpng versions 0.89c, June 1996, through 0.96, May 1997: Andreas Dilger
- * libpng versions 0.97, January 1998, through 1.5.15beta05 - February 17, 2013: Glenn
+ * libpng versions 0.97, January 1998, through 1.5.15beta05 - February 18, 2013: Glenn
* See also "Contributing Authors", below.
*
@@ -216,7 +216,7 @@
* This code is released under the libpng license.
*
- * libpng versions 1.2.6, August 15, 2004, through 1.5.15beta05, February 17, 2013, are
+ * libpng versions 1.2.6, August 15, 2004, through 1.5.15beta05, February 18, 2013, are
* Copyright (c) 2004, 2006-2013 Glenn Randers-Pehrson, and are
* distributed according to the same disclaimer and license as libpng-1.2.5